@@ -66,14 +66,18 @@ class BridgeError(Exception):
 class DynaliteDevices:
     """Manages a single Dynalite bridge."""
 
-    def __init__(self, new_device_func: Callable, update_device_func: Callable) -> None:
+    def __init__(
+        self,
+        new_device_func: Callable[[List[DynaliteBaseDevice]], None],
+        update_device_func: Callable[[Union[DynaliteBaseDevice, str]], None],
+    ) -> None:
         """Initialize the system."""
         self._host = ""
         self._port = 0
         self.name = None  # public
         self._poll_timer = 0.0
         self._default_fade = 0.0
-        self._active = False
+        self._active = ""
         self._auto_discover = None
         self._loop: Optional[asyncio.AbstractEventLoop] = None
         self._new_device_func = new_device_func
@@ -86,7 +90,7 @@ class DynaliteDevices:
         self._added_time_covers: Dict[int, Any] = {}
         self._waiting_devices: List[DynaliteBaseDevice] = []
         self._timer_active = False
-        self._timer_callbacks: Set[Callable] = set()
+        self._timer_callbacks: Set[Callable[[], None]] = set()
         self._area: Dict[int, Any] = {}
         self._dynalite = Dynalite(broadcast_func=self.handle_event)
         self._resetting = False
@@ -372,7 +376,7 @@ class DynaliteDevices:
                 channel_to_set.stop_fade()
                 self.update_device(channel_to_set)
 
-    def add_timer_listener(self, callback_func: Callable) -> None:
+    def add_timer_listener(self, callback_func: Callable[[], None]) -> None:
         """Add a listener to the timer and start if needed."""
         self._timer_callbacks.add(callback_func)
         if not self._timer_active:
@@ -380,7 +384,7 @@ class DynaliteDevices:
             self._loop.call_later(self._poll_timer, self.timer_func)
             self._timer_active = True
 
-    def remove_timer_listener(self, callback_func: Callable) -> None:
+    def remove_timer_listener(self, callback_func: Callable[[], None]) -> None:
         """Remove a listener from a timer."""
         self._timer_callbacks.discard(callback_func)
 
@@ -411,7 +415,10 @@ class DynaliteDevices:
 
     def get_channel_name(self, area: int, channel: int) -> str:
         """Return the name of a channel."""
-        return f"{self._area[area][CONF_NAME]} {self._area[area][CONF_CHANNEL][channel][CONF_NAME]}"
+        cur_area = self._area.get(area, {})
+        default_area_name = f"Area {area}"
+        default_channel_name = f"Channel {channel}"
+        return f"{cur_area.get(CONF_NAME, default_area_name)} {cur_area.get(CONF_CHANNEL, {}).get(channel, {}).get(CONF_NAME, default_channel_name)}"
 
     def get_channel_fade(self, area: int, channel: int) -> float:
         """Return the fade of a channel."""
@@ -419,7 +426,10 @@ class DynaliteDevices:
 
     def get_preset_name(self, area: int, preset: int) -> str:
         """Return the name of a preset."""
-        return f"{self._area[area][CONF_NAME]} {self._area[area][CONF_PRESET][preset][CONF_NAME]}"
+        cur_area = self._area.get(area, {})
+        default_area_name = f"Area {area}"
+        default_preset_name = f"Preset {preset}"
+        return f"{cur_area.get(CONF_NAME, default_area_name)} {cur_area.get(CONF_PRESET, {}).get(preset, {}).get(CONF_NAME, default_preset_name)}"
 
     def get_preset_fade(self, area: int, preset: int) -> float:
         """Return the fade of a preset."""
@@ -451,7 +461,7 @@ class DynaliteDevices:
             master_area = override_area if override_area.lower() != CONF_NONE else ""
         return master_area
 
-    async def async_reset(self):
+    async def async_reset(self) -> None:
         """Reset the connections and timers."""
         self._resetting = True
         await self._dynalite.async_reset()
